#
# spec file for package spice-up
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.philip_scott.spice-up
Name:           spice-up
Version:        1.9.1
Release:        2.1
Summary:        Desktop presentation application
License:        GPL-3.0-only
URL:            https://github.com/Philip-Scott/Spice-up
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  vala > 0.48.0
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite) >= 0.5
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libsoup-2.4)

%description
Spice-up is a desktop presentation application
based upon SpiceOfDesign's presentation concept.

%lang_package

%prep
%autosetup -n Spice-up-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%{_datadir}/mime/packages/%{appid}.mime.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Mon Nov 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update spec file for Leap 16.0:
  * remove recommending lang package
  * use autosetup
  * remove HiDPI workaround
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.9.1:
  * AppData: Add info for a hotfix release
  * Merge branch 'master' of github.com:Philip-Scott/Spice-up
  * SlideList: Prevent slides from expanding on window resize
  * AppData: less verbose OARS (#325)
  * Use show_uri_on_window for editing images
  * SlideList: Make the "Add a Slide" button full size
  * elementary 6+ release
  * Stylesheet: imitate box shadow from system (#324)
  * SlideList: code and style cleanup (#323)
  * Granite.App → Gtk.App (#322)
  * Modernize Icons (#321)
  * EntryCombo: use button style (#317)
  * HeaderBar: Use insert-* namespace for icons (#318)
  * Fix warnings with casts (#319)
  * CSS: Use raised class instead of custom CSS (#314)
  * Build with Flatpak (#306)
  * Window: Remove DnD handling (#313)
  * GradientEditor: fix oval selectors (#315)
  * SlideList: Use text/image button in actionbar (#316)
  * Window: Use Gtk.Application.Inhibit (#309)
  * FileManager: use file chooser portal (#307)
  * Build with Meson (#308)
  * Fix build with vala 0.46 (#296)
  * Downgrade Node.js to fix builds on Travis CI (#289)
  * Black background on fullscreen (#286)
  * Update ISSUE_TEMPLATE.md
- Drop spice-up-1.8.2-vala-0.46.patch
- Switch to meson
* Thu Oct 31 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add spice-up-1.8.2-vala-0.46.patch
* Mon May  6 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.2:
  * Add Issue and PR Templates
  * 1.8.1 Release
  * Removed remote templates service
  * Invert logic of history_is_enabled
  * Respect privacy settings using Granite (#260)
  * Require Gtk3.22 - Dropped support for older Gtk versions
  * Update fr.po (#261)
* Mon Jan 21 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.8.0:
  * Autohide cursor while presenting
  * Move the rest of the actions to the Main Window
  * Move Insertion actions to Window Actions
  * Move Headerbar actions to Window Actions
  * Allow more than one window
  * Move current_file to window
  * Move history manager to Window
  * Remove global window variable
  * Undo,Redo,Clone
  * Add .pdf extension to exports
  * Prevent screen from turning off during presentations
  * Grab focus when PresenterNotes is revealed
  * Use new Granite.markup_accel_tooltip & Add actions for clone
    and present
  * Handle unfullscreening while presenting
  * Fixed: Animation on canvas is played when returning from the
    last slide while presenting
  * Fix: Property with custom 'get' / 'set' cannot have 'default'
    value (#251)
  * update travis.yml (#252)
  * Use user cache folder for template cache
  * Update com.github.philip-scott.spice-up.appdata.xml
  * Update README.md
  * Canvas: fixed precision problems on different sizes
  * Smart clipboard v2 (#239)
  * Smart Clipboard (#233)
  * Fix SlideWidget shadows not showing up
  * Color picker refactoring (#238)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.1:
  * Remote templates v2 (#237)
* Mon Sep 24 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.0:
  * Code cleanups
  * Slide Transitions (#236)
  * Add: PresenterNotes.vala
  * Add option to set a slide as the File Preview
  * SlideList: Right click actions
  * Add presenter notes to main view
  * Move button creation to function
  * SlideList: Add separator and fix styles
  * Add new slide after selected one
  * Stick new slide button
  * Fix: Empty slides not rendering in slide list
  * Set accent color & use that on slide list
* Mon Sep 10 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.2:
  * Update com.github.philip-scott.spice-up.appdata.xml
  * LibraryItem: Don't show popover on templates
  * Rename com.github.philip_scott.spice_up.mime.xml to
    com.github.philip-scott.spice-up.mime.xml
  * Update CMakeLists.txt
  * Update and rename
    com.github.philip_scott.spice_up.appdata.xml to
    com.github.philip-scott.spice-up.appdata.xml
  * PresenterView: Change font-size with +/- keys
  * Be smart about the mutex
  * allow whitespace between commas on gradient regex
  * Improve item positioning rounding
  * Fix crash when moving a slide past the end
  * Update RDNN name (#219)
* Thu Aug 23 2018 avvissu@yandex.by
- Update to 1.5.1:
  * Update README.md
  * Updated appdata for 1.5 release
  * Load more templates from external server (#217)
  * Fix color picker not updating
  * Add new gradients to the palette
  * Add new colors to palette
  * Fix disabled button icons not getting styled correctly
  * PickerWindow: Remove deprecated warnings
  * Show filename under thumbnail
  * ColorPicker: Don't grab all key events
  * Fix extra padding on grabbers in Gtk3.22
  * Fix text entry styles on Gtk3.22
  * Copy & Paste from color picker
  * Remove about option from desktop entry (#202)
  * Add OARS information
  * Update Pt_pt (#198)
  * Updated screenshot
- Change the home page
- Add pkgconfig(libsoup-2.4)
- Switch to vala >= 0.40.4
- Remove obsolete macros
* Thu Jun 14 2018 avvissu@yandex.by
- Change the Group tag to Productivity/Office/Other
* Fri Feb 23 2018 avvissu@yandex.by
- Update to 1.3.2:
  * Use elementary color palette with the icons
  * Selected style on Gradient Editor Nubs
  * Keep track of previous selected step
  * Merge branch 'master' of github.com:Philip-Scott/Spice-up
  * add custom color picker icons
* Fri Feb  9 2018 avvissu@yandex.by
- Update to 1.3.0:
  * Prevent accidental background image changes
  * Disable notifications while presenting
  * Font style with markup (#193)
  * Add new tooltips
  * Make UI icons symbolic
  * Add gradient palette
  * Reset canceled color from picker properly
  * Merge branch 'master' of github.com:Philip-Scott/Spice-up
  * Updated screenshot
  * Color picker makeover (#189)
  * TextBar.vala: Make font-style EntryCombo uneditable (#188)
  * Search fonts (#186)
  * Fix font picker styles on Gtk3.22
* Sat Jan  6 2018 avvissu@yandex.by
- Update to 1.2.1:
  * Don't override the system CFLAGS
  * Fix appdata validations
  * More image validations
  * Add Screenshot4.png
  * Clickable next-preview
  * Gtk 3.22 fixes
  * Fix small typo.
  * Connect end of presentation slide
  * Refactored Ligrary and Template view into one
  * Add missing element to empty slide json
  * Always open PresenterView with -d
  * Add the Presentation view
  * Add Slideshow Controller
  * Use SlideWidget
  * Create and use SlideWidget
  * Load edit and save slide notes
  * End of presentation slide added
  * Prevent loading a null slide preview
  * Use Gdk.Cursor.from_name
  * PresenterWindow tweaks
* Sun Nov 19 2017 avvissu@yandex.by
- Remove smp_mflags to avoid compilation errors
* Sat Nov  4 2017 avvissu@yandex.by
- Update to 1.1.0:
  * Add images on Drag & Drop
  * Update README.md
  * Update com.github.philip-scott.spice-up.appdata.xml
* Wed Oct 18 2017 avvissu@yandex.by
- Update to 1.0.1:
  * Create pull_request_template.md
  * Fix screenshot
  * Catch NULL Documents folder
  * Allow future ViewerFiles to be open
  * Allow future viewer files to be openable
  * Scroll presentation with PgUp and PgDn
  * Reset ImageID when a new presentation loads
  * Lazy load slides
  * Text vertical alignment (#158)
  * Animate going back to the welcome screen
  * Change order of text toolbar
  * Move justification items to popover
* Mon Sep 18 2017 avvissu@yandex.by
- Update to 1.0.0:
  * Delete empty files
  * Saving a presentation with no content causes a crash on load
* Tue Sep 12 2017 avvissu@yandex.by
- Update to 0.9.0:
  * Update README.md
  * Add another screenshot
  * Update appdata & new screenshot
  * Roundness scale text now reads better
  * Allow for setting opacity on Text and Color items
  * Fix: Double clicking would sometimes unselect the item
  * Merge branch 'master' of github.com:Philip-Scott/Spice-up
  * Images: Add a way to replace them
  * Modify template format
  * New slide button not focusable
  * Put previous values on new canvas
  * New Presentation templates
  * Skip tests in Houston
  * Disable testing on displayless server
  * Update com.github.philip-scott.spice-up.appdata.xml
  * Update screenshots
  * Updated 128px icon
  * Add undo & redo shortcuts
  * Gtk 3.22 support (#138)
  * Slide list on click response
- Add a package with translations
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 0.8.1:
  * New icon & Add icon for different sizes (#134)
* Fri Jul 21 2017 avvissu@yandex.by
- Update to 0.8.0:
  * Move stylesheet to GResource
  * multi-threading library loading
  * Open file location
  * Don't ask where to save before you can use the app
  * Edit presentation properties from the browser
  * Revamped welcome screen
  * Copy, Cut and Paste from your keyboard
  * Add Roundness tooltip
  * Update last file when opening from Files
  * Moved main stylesheet & fix modebutton checked
  * ShapeItem: Set border radius
  * Update preview when adding/removing items
  * Exit presentation mode with Esc
  * Better raw image handling
  * Text to base64, fix crashes with special characters
  * Refactor image handling
* Sat Jul  1 2017 avvissu@yandex.by
- Update to 0.6.5:
  * Correcting MimeType in .desktop file.
  * misc code cleanups
  * Fix text undo
  * Make sure canvas items get freed from memory
  * Update first presentation
  * Add a way to launch an image editor
  * monitor file changes
  * Load images from file
  * Update com.github.philip-scott.spice-up.appdata.xml
  * Merge pull request #126 from danrabbit/patch-1
  * Update README.md
  * Bump version number
  * Clone button added
  * Readme reloaded (#125)
  * Add link to AppCenter
  * Style changes
  * Style the color popover
  * Better color palette
  * Added mimetype icon
  * Updated testing presentation
* Tue Jun 13 2017 jengelh@inai.de
- Ensure neutrality of description.
* Sat May 27 2017 avvissu@yandex.by
- Update to 0.5.5:
  * Move patterns to gresource
  * Fix: Justification not working correctly on one line
  * Added file checking for missing patterns, and pointed them to
    the right direction
  * Fixed: text on slides flashes when the window is resized
  * Fix delete & re-add icon to CMAKE
  * Fix: added .spice to all files
  * Update GResources.cmake
  * Use RDNN everywhere
  * Updated Screenshot
  * Don't constraint movement with fix_position
  * CommonBar: Changed tooltips
  * Save file with app's extension
  * CanvasItem: Min size Part2
  * CanvasItems: Min size
* Sat May 20 2017 avvissu@yandex.by
- Update to 0.4.6:
  * Use backspace for item deletion
  * stylize the slide list
  * Make new items use the properties of the previous one
  * remove margins on drag icon
  * Add non-standard icons to a gresource
  * Update CanvasItem.vala
* Mon May 15 2017 avvissu@yandex.by
- Update to 0.4.3:
  * Added configuration dialog
  * Merge branch 'master' into Controller-configuration
  * Add the defaults to controller config
  * Add title to controller dialog
  * Make sure to show all
* Sun May  7 2017 avvissu@yandex.by
- Update to 0.4.2:
  * Fixed: Can edit slides while presenting
  * Fixed: Fix shortcuts breaking typing
  * All text should now be translatable
  * Move though presentation mode using your keyboard
  * Use a JoyCon to control your slides in presentation mode
  * Fixed: Crashes if clicked when no slide was selected
  * Fixed: No gradient applied if there's no direction chosen
* Wed May  3 2017 avvissu@yandex.by
- Update to 0.3.6:
  * Open-with support for .spice files
  * A better looking icon
  * Previews are now stored on the file instead of re-making the canvas
- Add MIME databases
* Mon May  1 2017 avvissu@yandex.by
- Update to 0.3.5:
  * Update the Screenshot and the brand colors
  * Add appcenter brand colors & move appdata location
  * Trying to work around liftoff
  * Now with hopefully more screenshots
- Drop patches (fixed):
  * desktop.patch
  * appdata.patch
  * license.patch
* Sun Feb 26 2017 mailaender@opensuse.org
- initial packaging of version 0.2.7
